@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Authors: Don Welch
+# Authors: Don Welch, Naga Samrat Chowdary Narla
 #
 
 #from __future__ import generators
@@ -1476,10 +1476,12 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
 
                 for row, x in enumerate(self.cur_device.sorted_supplies):
                     a, agent_kind, agent_type, agent_sku = x
-                    agent_level = int(self.cur_device.dq['agent%d-level' % a])
-                    agent_desc = self.cur_device.dq['agent%d-desc' % a]
-                    agent_health_desc = self.cur_device.dq['agent%d-health-desc' % a]
-
+                    try:
+                        agent_level = int(self.cur_device.dq['agent%d-level' % a])
+                        agent_desc = self.cur_device.dq['agent%d-desc' % a]
+                        agent_health_desc = self.cur_device.dq['agent%d-health-desc' % a]
+                    except KeyError:
+                        break
                     # Bar graph level
                     level_pixmap = None
                     if agent_kind in (AGENT_KIND_SUPPLY,
@@ -1895,7 +1897,8 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
                 self.updatePrintController()
                 self.cur_device.sendEvent(e, self.cur_printer)
             else:
-                log.error("Start/Stop printer operation failed")
+                if os.geteuid!=0 and utils.addgroup()!=[]:
+                    FailureUI(self, self.__tr("<b>Start/Stop printer queue operation fails.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
 
         finally:
             endWaitCursor()
@@ -1924,9 +1927,9 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
             if result:
                 self.updatePrintController()
                 self.cur_device.sendEvent(e, self.cur_printer)
-            else:
-                log.error("Reject/Accept jobs operation failed")
-
+            else:  
+                if os.geteuid!=0 and utils.addgroup()!=[]:
+                    FailureUI(self, self.__tr("<b>Accept/Reject printer queue operation fails.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
 
         finally:
             endWaitCursor()
@@ -1938,7 +1941,8 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         try:
             result = cups.setDefaultPrinter(self.cur_printer.encode('utf8'))
             if not result:
-                log.error("Set default printer failed.")
+                if os.geteuid!=0 and utils.addgroup()!=[]:
+                    FailureUI(self, self.__tr("<b>Set printer queue as default operation fails.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
             else:
                 self.updatePrintController()
                 if self.cur_device.device_type == DEVICE_TYPE_PRINTER:
@@ -2034,7 +2038,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         if utils.which('hp-setup'):
             cmd = 'hp-setup --gui'
         else:
-            cmd = '/usr/local/bin/python2.5 ./setup.py --gui'
+            cmd = '/usr/local/bin/python2.6 ./setup.py --gui'
 
         log.debug(cmd)
         utils.run(cmd, log_output=True, password_func=None, timeout=1)
@@ -2046,7 +2050,7 @@ class DevMgr5(QMainWindow,  Ui_MainWindow):
         if utils.which('hp-setup'):
             cmd = 'hp-setup --gui --remove'
         else:
-            cmd = '/usr/local/bin/python2.5 ./setup.py --gui --remove'
+            cmd = '/usr/local/bin/python2.6 ./setup.py --gui --remove'
 
         if self.cur_device_uri is not None:
             cmd += ' --device=%s' % self.cur_device_uri
