@@ -16,12 +16,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Authors: Don Welch
+# Authors: Don Welch, Naga Samrat Chowdary Narla
 #
 
 # StdLib
 import socket
 import operator
+import commands
 
 # Local
 from base.g import *
@@ -212,6 +213,7 @@ class SetupDialog(QDialog, Ui_Dialog):
         self.advanced = False
         self.manual = False
         self.skip_discovery = False
+        self.discovery_method = 0
         self.NetworkRadioButton.setEnabled(prop.net_build)
         self.WirelessButton.setEnabled(prop.net_build)
         self.ParallelRadioButton.setEnabled(prop.par_build)
@@ -312,11 +314,11 @@ class SetupDialog(QDialog, Ui_Dialog):
 
 
     def manualDiscovery(self):
-        ret = False
         # Validate param...
         device_uri, sane_uri, fax_uri = device.makeURI(self.param, self.jd_port)
 
         if device_uri:
+            log.info("Found device: %s" % device_uri)
             back_end, is_hp, bus, model, serial, dev_file, host, zc, port = \
                 device.parseDeviceURI(device_uri)
 
@@ -341,9 +343,10 @@ class SetupDialog(QDialog, Ui_Dialog):
                 self.ParallelRadioButton.setChecked(True)
                 self.setParallelRadioButton(True)
 
-            ret = True
+            return True
 
-        return ret
+
+        return False
 
 
     def ManualGroupBox_clicked(self, checked):
@@ -738,7 +741,10 @@ class SetupDialog(QDialog, Ui_Dialog):
             log.debug("Searching for fax PPD for model %s" % self.model)
 
             if prop.hpcups_build:
-                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP:
+                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_MARVELL:
+                    fax_ppd_name = "HP-Fax3-hpcups" # Fixed width (2528 pixels) and 300dpi rendering
+                    nick = "HP Fax3 hpcups"
+                elif self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP:
                     fax_ppd_name = "HP-Fax2-hpcups" # Fixed width (2528 pixels) and 300dpi rendering
                     nick = "HP Fax2 hpcups"
                 else:
@@ -746,6 +752,9 @@ class SetupDialog(QDialog, Ui_Dialog):
                     nick = "HP Fax hpcups"
 
             else: # hpijs
+                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_MARVELL:
+                    fax_ppd_name = "HP-Fax3-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
+                    nick = "HP Fax3 hpijs"
                 if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP:
                     fax_ppd_name = "HP-Fax2-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
                     nick = "HP Fax2 hpijs"
@@ -969,7 +978,8 @@ class SetupDialog(QDialog, Ui_Dialog):
                 self.printer_name not in self.installed_print_devices[self.device_uri]:
 
                 QApplication.restoreOverrideCursor()
-                FailureUI(self, self.__tr("<b>Printer queue setup failed.</b><p>Please restart CUPS and try again."))
+                if os.geteuid!=0 and utils.addgroup()!=[]:
+                    FailureUI(self, self.__tr("<b>Printer queue setup failed.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
             else:
                 # TODO:
                 #service.sendEvent(self.hpssd_sock, EVENT_CUPS_QUEUES_CHANGED, device_uri=self.device_uri)
@@ -1236,8 +1246,8 @@ class SetupDialog(QDialog, Ui_Dialog):
                     item = self.RemoveDevicesTableWidget.item(row, 1)
                     printer = unicode(item.data(Qt.UserRole).toString()).encode('utf-8')
                     log.debug("Removing printer: %s" % printer)
-                    cups.delPrinter(printer)
-
+                    if cups.delPrinter(printer) == 0 and os.geteuid!=0 and utils.addgroup()!=[]:
+                            FailureUI(self, self.__tr("<b>Unable to delete printer queue.</b><p>Please add user to %s group(s)" %utils.list_to_string(utils.addgroup())))
             self.close()
 
         else:
